import React, { useEffect, useMemo, useRef, useState } from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { useList } from './hooks';
import { classNames, getRect } from './utils';

import './style.less'

export default (props) => {
  const { className, itemClassName, style, gutter = 0, list, render, ...leftProps } = props

  const splitStyle = { width: `${gutter}rpx` }

  const leftBottom = useRef(0)
  const rightBottom = useRef(0)
  const [leftList, leftRef, setLeftList] = useList()
  const [rightList, rightRef, setRightList] = useList()
  const vidRef = useRef()
  const [cursor, setCursor] = useState(-1)

  const listRef = useRef([])
  listRef.current = list
    
  useEffect(() => {
    if (list && list.length) {
      setCursor(0)
    } else {
      setCursor(-1)
      setLeftList([])
      setRightList([])
    }
  }, [list])

  useEffect(() => {
    const len = !listRef.current ? 0 : listRef.current.length;

    if (leftRef.current.length + rightRef.current.length >= len) return;

    const item = listRef.current[cursor] || {}
    item.__vid = `f-${Math.random().toString(36).substring(2)}`
    vidRef.current = item.__vid

    if (leftBottom.current <= rightBottom.current) {
      setLeftList([...leftRef.current, item])
    } else {
      setRightList([...rightRef.current, item])
    }
  }, [cursor])

  useEffect(() => {
    const setHeight = (rect) => {
      const { bottom } = rect
      if (cursor % 2 === 0) {
        leftBottom.current = bottom
      } else {
        rightBottom.current = bottom
      }
      setCursor(cursor + 1)
    }

    const calcHeight = () => {
      getRect(`.${vidRef.current}`).then((res) => {
        if (!res) {
          // 找不到 node , 则一直重复查询
          const t = setTimeout(() => {
            clearTimeout(t)
            calcHeight()
          }, 300)
        } else {
          if (Array.isArray(res)) {
            setHeight(res[0])
          } else {
            setHeight(res)
          }
        }
      })
    }

    calcHeight()
  })

  return (
    <View
      className={classNames(className, 'masonry-layout')}
      style={style}
    >
      <View className='masonry-column'>
        {
          leftList.map((item) => (
            <View key={item.__vid} className={classNames(itemClassName, 'masonry-item', item.__vid)}>{render(item)}</View>
          ))
        }
      </View>
      <View className='masonry-split' style={splitStyle} />
      <View className='masonry-column'>
        {
          rightList.map((item) => (
            <View key={item.__vid} className={classNames(itemClassName, 'masonry-item', item.__vid)}>{render(item)}</View>
          ))
        }
      </View>
    </View>
  )
}
